#Copyright (c) 2012 Luminoso, LLC
#
#Permission is hereby granted, free of charge, to any person obtaining a
#copy of this software and associated documentation files (the "Software"),
#to deal in the Software without restriction, including without limitation
#the rights to use, copy, modify, merge, publish, distribute, sublicense,
#and/or sell copies of the Software, and to permit persons to whom the
#Software is furnished to do so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in
#all copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#DEALINGS IN THE SOFTWARE.

# Load timestamp methods
from datetime import datetime
from time import mktime

def datetime2epoch(dt):
    """Convert a datetime object into milliseconds from epoch"""
    return int(mktime(dt.timetuple())*1000)

def epoch2datetime(t):
    """Convert milliseconds from epoch to a local datetime object"""
    return datetime.fromtimestamp(t/1000.0)

def epoch():
    """Get the current time in milliseconds from epoch"""
    return datetime2epoch(datetime.now())



from setuptools import setup
import sys

CLASSIFIERS = ['License :: OSI Approved :: MIT License']

setup(
    name="jstime",
    version = '1.0',
    maintainer='Luminoso, LLC',
    maintainer_email='dev@lumino.so',
    classifiers=CLASSIFIERS,
    url = 'http://github.com/LuminosoInsight/jstime',
    platforms = ["any"],
    description = "Convert python datatime objects to/from milliseconds from epoch",
    py_modules=['jstime'],
)
